==> bucket-list-0.3.tar.gz: bucket-list-0.3/bucketlist/commands/backup.py <==
import json
import getopt

from bucketlist import speedyio, appconfig
from bucketlist.errors import BucketlistError
from bucketlist.providers import get_current_provider


class BackupCommand:
    __command_name__ = 'backup'

    def __init__(self):
        pass

    def dump(self, data, file_path):
        with open(file_path, 'w') as f:
            json.dump(data, f, sort_keys=True, indent=4)

    def execute(self, argv):
        Provider = get_current_provider()

        optlist, args = getopt.getopt(argv, '', ['file='])
        optmap = {
            opt[0].lstrip('-'):opt[1]
            for opt in optlist
        }

        if 'file' not in optmap:
            optmap['file'] = speedyio.askfor('file', empty_allowed=False)

        try:
            with open(optmap['file'], 'w') as f:
                f.write('')
        except Exception as e:
            raise BucketlistError(str(e))

        provider_name = appconfig.get('provider', 'name')
        backup_data = {
            'provider': provider_name,
        }

        data = {}
        categories = Provider.get_categories()
        speedyio.info("{} categories fetched".format(len(categories)))
        for category in categories:

            tasks_incomplete = Provider.get(category.name, completed=False)
            speedyio.info("{} incomplete items fetched for category {}".format(len(tasks_incomplete), category.name))

            tasks_complete = Provider.get(category.name, completed=True)
            speedyio.info("{} completed items fetched for category {}".format(len(tasks_complete), category.name))

            data[category.name] = [t.__dict__ for t in tasks_incomplete + tasks_complete]

        backup_data['data'] = data

        self.dump(backup_data, optmap['file'])
        speedyio.success("Backup successfully created at {}".format(optmap['file']))

==> bucket-list-0.3.3.tar.gz: bucket-list-0.3.3/bucketlist/commands/backup.py <==
import json
import getopt

from bucketlist import speedyio, appconfig
from bucketlist.errors import BucketlistError
from bucketlist.providers import get_current_provider


class BackupCommand:
    __command_name__ = 'backup'

    def dump(self, data, file_path):
        with open(file_path, 'w') as f:
            json.dump(data, f, sort_keys=True, indent=4)

    def execute(self, argv):
        Provider = get_current_provider()

        optlist, args = getopt.getopt(argv, '', ['file='])
        optmap = {
            opt[0].lstrip('-'):opt[1]
            for opt in optlist
        }

        if 'file' not in optmap:
            optmap['file'] = speedyio.askfor('file', empty_allowed=False)

        try:
            with open(optmap['file'], 'w') as f:
                f.write('')
        except Exception as e:
            raise BucketlistError(str(e))

        provider_name = appconfig.get('provider', 'name')
        backup_data = {
            'provider': provider_name,
        }

        data = {}
        categories = Provider.get_categories()
        speedyio.info("{} categories fetched".format(len(categories)))
        for category in categories:

            tasks_incomplete = Provider.get_items(category, completed=False)
            speedyio.info("{} incomplete items fetched for category {}".format(len(tasks_incomplete), category.name))

            tasks_complete = Provider.get_items(category, completed=True)
            speedyio.info("{} completed items fetched for category {}".format(len(tasks_complete), category.name))

            data[category.name] = [t.__dict__ for t in tasks_incomplete + tasks_complete]

        backup_data['data'] = data

        self.dump(backup_data, optmap['file'])
        speedyio.success("Backup successfully created at {}".format(optmap['file']))
